translate.storage.omegat.OmegaTDialect

Package translate :: Package storage :: Module omegat :: Class OmegaTDialect |
[hide private]
[frames] | no frames]

# Class OmegaTDialect

source code

Describe the properties of an OmegaT generated TAB-delimited file.

Instance Methods | [hide private]
Inherited from `csv.Dialect`: `__init__` Inherited from `csv.Dialect` (private): `_validate`

Class Variables | [hide private]
| delimiter = `"\t"`
| lineterminator = `"\r\n"`
| quoting = `csv.QUOTE_MINIMAL`
| doublequote = `False` Parse an instance of this class from the start of the given string.
| skipinitialspace = `False` Parse an instance of this class from the start of the given string.
| escapechar = `None` Parse an instance of this class from the start of the given string.
| quotechar = `'"'`
Inherited from `csv.Dialect` (private): `_name`, `_valid`